@@ -83,6 +83,14 @@ where
         }
     }
 
+    #[emitter]
+    fn emit_import_supports_type(&mut self, n: &ImportSupportsType) -> Result {
+        match n {
+            ImportSupportsType::SupportsCondition(n) => emit!(self, n),
+            ImportSupportsType::Declaration(n) => emit!(self, n),
+        }
+    }
+
     #[emitter]
     fn emit_charset_rule(&mut self, n: &CharsetRule) -> Result {
         punct!(self, "@");
@@ -95,6 +103,34 @@ where
         semi!(self);
     }
 
+    #[emitter]
+    fn emit_import_rule(&mut self, n: &ImportRule) -> Result {
+        punct!(self, "@");
+        keyword!(self, "import");
+        space!(self);
+        emit!(self, n.href);
+
+        if let Some(layer_name) = &n.layer_name {
+            space!(self);
+            emit!(self, layer_name);
+        }
+
+        if let Some(supports) = &n.supports {
+            space!(self);
+            keyword!(self, "supports");
+            punct!(self, "(");
+            emit!(self, supports);
+            punct!(self, ")");
+        }
+
+        if let Some(media) = &n.media {
+            space!(self);
+            emit!(self, media);
+        }
+
+        semi!(self);
+    }
+
     #[emitter]
     fn emit_import_href(&mut self, n: &ImportHref) -> Result {
         match n {
@@ -112,26 +148,6 @@ where
         }
     }
 
-    #[emitter]
-    fn emit_import_rule(&mut self, n: &ImportRule) -> Result {
-        punct!(self, "@");
-        keyword!(self, "import");
-        space!(self);
-        emit!(self, n.href);
-
-        if let Some(layer_name) = &n.layer_name {
-            space!(self);
-            emit!(self, layer_name);
-        }
-
-        if let Some(media) = &n.media {
-            space!(self);
-            emit!(self, media);
-        }
-
-        semi!(self);
-    }
-
     #[emitter]
     fn emit_font_face_rule(&mut self, n: &FontFaceRule) -> Result {
         punct!(self, "@");
